<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ast">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="76"/>
        <source>Enter the number to configure: </source>
        <translation>Introduzca el número pa configurar: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="81"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceutar</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="16"/>
        <source>Loading packages...</source>
        <translation>Cargando paquetes...</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="17"/>
        <source>%1/%2 loaded</source>
        <translation>%1/%2 cargados</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="20"/>
        <source>Initializing...</source>
        <translation>Inicializando...</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="17"/>
        <source>OK</source>
        <translation>Aceutar</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="107"/>
        <source>Package Installer</source>
        <translation>Xestor de paquetes</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="115"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="598"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>Instalando otros paquetes... Por favor, abriéntolo más tarde.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="602"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>Parseo falló: Se encontró una estructura de fichero ilegal nel fichero de manifiesto!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="604"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>Parseo falló: Se encontró un número de versión ilegal nel fichero de manifiesto!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="606"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>Nun se encontraron paquetes deb. Por favor, revise la carpeta.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="718"/>
        <source>The %1 package may be broken</source>
        <translation>El paquete %1 podría estar roto</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="726"/>
        <source>You can only install local %1 packages</source>
        <translation>Só se pue instalar paquetes %1 locales</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="734"/>
        <source>No permission to access this folder</source>
        <translation>Nun hai permisu pa acceder a esta carpeta</translation>
    </message>
    <message>
        <source>The deb package may be broken</source>
        <translation>El paquete deb podría estar roto</translation>
    </message>
    <message>
        <source>You can only install local deb packages</source>
        <translation>Só se pue instalar paquetes deb locales</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="750"/>
        <source>Already Added</source>
        <translation>Ya añadíu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="759"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1 nun esiste, por favor, reseleccione</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="381"/>
        <source>Bulk Install</source>
        <translation>Instalación masiva</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="94"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Falló la instalación, comprueba la to conexón d'internet</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="97"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>La instalación falló, por favor, revise les actualizaciones nel Centro de Control</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="99"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Falló la instalación, espaciu insuficiente en discu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="120"/>
        <source>No digital signature</source>
        <translation>Nun hai firma digital</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="124"/>
        <source>Invalid digital signature</source>
        <translation>Firma digital inválida</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="130"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>El administrador estableció polítiques pa evitar la instalación d'este paquete</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="136"/>
        <source>Installation Failed</source>
        <translation>Falló la instalación</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="732"/>
        <source>current system</source>
        <translation>sistema actual</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="735"/>
        <source>%2 has been installed in %1, please uninstall this package before installing it</source>
        <translation>%2 ta instaláu en %1, por favor, desinstale este paquete antes de instalarlo</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="741"/>
        <source>Broken dependencies, try installing the app in compatibility mode</source>
        <translation>Dependencias rotas, intente instalar l'aplicación en modu de compatibilidá</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="756"/>
        <source>Failed to install %1</source>
        <translation>Fallo na instalación de %1</translation>
    </message>
    <message>
        <source>Failed to install %1: no valid digital singature</source>
        <translation>Fallo na instalación de %1: nun hai firma digital válida</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1116"/>
        <source>Unable to install - no digital signature</source>
        <translation>Nun se pue instalar - nun hai firma digital</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1117"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>Por favor, vaya al Centro de Control pa habilitar el modu de desenvolutor y intente nuevamente. Continuar?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1120"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1121"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1074"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceutar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1078"/>
        <source>Failed to install %1: no valid digital signature</source>
        <translation>Fallo na instalación de %1: nun hai firma digital válida</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1214"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>Este paquete nun tien una firma digital válida. Continuar con la instalación?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1216"/>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1217"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continua</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1072"/>
        <source>Unable to install</source>
        <translation>No se puede instalar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1174"/>
        <source>This package does not have a valid digital signature</source>
        <translation>Este paquete nun tien una firma digital válida</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="759"/>
        <source>Broken dependencies: %1</source>
        <translation>Dependencias rotas: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="128"/>
        <source>Authentication failed</source>
        <translation>Autenticación fallida</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="711"/>
        <source>Unmatched package architecture</source>
        <translation>Arquitectura de paquete que nun concasa</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="48"/>
        <source>Drag deb packages here</source>
        <translation>Arrastra paquetes deb aquí</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="90"/>
        <source>Select File</source>
        <translation>Esbillar ficheru</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="34"/>
        <source>Show details</source>
        <translation>Mostrar detalles</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="34"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Contrayer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="169"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="170"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Fecho</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="172"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="501"/>
        <source>Install %1 will remove: </source>
        <translation>La instalación de %1 eliminará: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="517"/>
        <source>Dependencies in the repository</source>
        <translation>Dependencias nel repositorio</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="523"/>
        <source>Missing dependencies</source>
        <translation>Dependencias faltantes</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="575"/>
        <source>Installing dependencies: %1</source>
        <translation>Instalando dependencias: %1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="82"/>
        <source>Same version installed</source>
        <translation>Instalada la mesma versión</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="85"/>
        <source>Earlier version installed: %1</source>
        <translation>Instalóse una versión anterior: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="89"/>
        <source>Later version installed: %1</source>
        <translation>Versión posterior instalada: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="94"/>
        <source>Unmatched package architecture</source>
        <translation>Arquitectura de paquete que nun concasa</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="22"/>
        <source>Select all</source>
        <translation>Selecciona todos</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="23"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Instalar</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="57"/>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="61"/>
        <source>Installed</source>
        <translation>Instalóse</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="69"/>
        <source>Failed</source>
        <translation>Falló</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="65"/>
        <source>Waiting</source>
        <translation>Esperando</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="232"/>
        <source>Same version installed</source>
        <translation>Instalada la mesma versión</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="234"/>
        <source>Later version installed: %1</source>
        <translation>Versión posterior instalada: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="236"/>
        <source>Earlier version installed: %1</source>
        <translation>Instalóse una versión anterior: %1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="161"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="31"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Contrayer</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>Comproba las firmas digitales si el mode de desenvolvedor ta habilitáu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="82"/>
        <source>To install unsigned apps, go to Security Center > Tools > App Security, and select the app types that can be installed.</source>
        <translation>Pa instalar aplicaciones non firmadas, vaya a Center de Seguridad > Herramientas > Seguridad de Aplicación, y seleccione los tipos d'aplicación que pueden instalase.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="84"/>
        <source>Security Center > Tools > App Security</source>
        <translation>Center de Seguridad > Herramientas > Seguridad de Aplicación</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/uab/uab_package.cpp" line="45"/>
        <source>The system has not installed Linglong environment, please install it first</source>
        <translation>El sistema nun ta instaláu l'entornu Linglong, por favor instálalo primeru</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="42"/>
        <source>Unable to install</source>
        <translation>No se puede instalar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="44"/>
        <source>This package does not have a valid digital signature and has been blocked from installing/running. Go to Security Center > Tools > App Security to change the settings.</source>
        <translation>Este paquete nun tien una firma digital válida y ta bloquedu pa instalar/ executar. Vaya a Center de Seguridad > Herramientas > Seguridad de Aplicación pa cambiar los parámetros.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="47"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anula</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="48"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Continua</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="264"/>
        <source>Will remove: </source>
        <translation>Eliminará: </translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="974"/>
        <source>Collapse</source>
        <translation>Contrayer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="482"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1155"/>
        <source>Later version installed: %1</source>
        <translation>Versión posterior instalada: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1156"/>
        <source>Downgrade</source>
        <translation>Descalafate</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1160"/>
        <source>Earlier version installed: %1</source>
        <translation>Instalóse una versión anterior: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1243"/>
        <source>Installing dependencies: %1</source>
        <translation>Instalando dependencias: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1390"/>
        <source>Failed to install %1</source>
        <translation>Falló l'instalación de %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="228"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="177"/>
        <source>Select a compatibility mode:</source>
        <translation>Selecciona un modu de compatibilidad:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="474"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="478"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="486"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceutar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="490"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="494"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Fecho</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="731"/>
        <source>Trying to install %2 in %1 compatibility mode</source>
        <translation>Intentando instalar %2 en modu de compatibilidad %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="808"/>
        <source>Uninstalling %2 from %1 compatibility mode</source>
        <translation>Desinstalando %2 de modu de compatibilidad %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="928"/>
        <source>%2 was successfully installed to %1 compatibility mode</source>
        <translation>%2 foi instaláu con éxito en modu de compatibilidad %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="932"/>
        <source>Installed successfully</source>
        <translation>Instalóse con ésitu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="941"/>
        <source>%2 has been successfully uninstalled from %1 compatibility mode</source>
        <translation>%2 foi desinstaláu con éxito de modu de compatibilidad %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="945"/>
        <source>Uninstalled successfully</source>
        <translation>Desinstalóse con ésitu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="964"/>
        <source>Uninstall Failed</source>
        <translation>Falló la desinstalación</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1004"/>
        <source>Install %1 will remove: </source>
        <translation>La instalación de %1 va eliminar: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1024"/>
        <source>Dependencies in the repository</source>
        <translation>Dependencies nel repositoriu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1030"/>
        <source>Missing dependencies</source>
        <translation>Dependencias faltantes</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1161"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1395"/>
        <source>Invalid digital signature</source>
        <translation>Firma digital inválida</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="216"/>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1150"/>
        <source>Same version installed</source>
        <translation>Instalada la mesma versión</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="49"/>
        <source>Show details</source>
        <translation>Mostrar detalles</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="31"/>
        <source>Show dependencies</source>
        <translation>Mostrar dependencies</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="794"/>
        <source>Show details</source>
        <translation>Mostrar detalles</translation>
    </message>
</context>
<context>
    <name>Uab::UabPackageListModel</name>
    <message>
        <location filename="../src/deb-installer/uab/uab_package_list_model.cpp" line="456"/>
        <source>Installation Failed</source>
        <translation>Falló la instalación</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Show related packages</source>
        <translation>Mostrar paquetes relacionaos</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Contrayer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="129"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>¿Seguro que quier desinstalar %1?
Todas las dependencies serán eliminadas tamién</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="131"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>¿Seguro que quier desinstalar %1?
El sistema o otras aplicaciónes pue non funcionar adecuadamente</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="169"/>
        <source>Are you sure you want to uninstall %2 
from %1 compatibility mode?</source>
        <translation>¿Seguro que quier desinstalar %2 
del modu de compatibilidad %1?</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="47"/>
        <source>Package Installer</source>
        <translation>Xestor de paquetes</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>Instalador de paquetes axuda a los usuarios a instalar y eliminar paquetes locales, y
soporta instalación en masa.</translation>
    </message>
</context>
</TS>
